bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 10. Aventiure
___________________________________________________
| ### ANDERTHalp des rines sach man mit manigen sharn ### den chvnich mit sinen gesten zv dem stade varn ### ovch sah man da bi zovme leiten manige meit ### di si enpfahen solden di waren alle bereit ### Do di von Islande cen sehffen chomen dan ### vnt ovch von Nibelvngen di Sifrides man ### si gahent zv dem lande vmmvezech wart ir hant ### da man des chvniges vrivnde des stades anderthalben vant
###### 578 | ### Nv hoeret <ovh> disiv mære von der chvnegin ### Vten di richen wi si div magedin ### frvmte von der bvrge dar si do selbe reit ### da gewan ein ander chvnde vil manich riter vnt meit [316b]
| ### Der herzoge Gere Crimhilt zvomte dan ### niwar fver daz bvrgetor Sifrit der chvene man ### der mvst ir fverbaz dienen si was ein shone chint ### des wart im wol gelonet von der ivnch vrowen sint
###### 580 | ### Ortwin der chvne bi vrov Vten reit ### vil gesellechlichen manich riter vnd meit ### ce so grozem antpfange des wir wol mvegen iehen ### wart nie so vil der vrowen bi ein ander gesæhen
###### 581 | ### Vil manich bvhvrt richer wart da getriben ### von helden <loblichen> niht wol daz wære beliben ### vor Crimhilt <der> vil shonen zv den schiffen dan ### do hvp <man> von den moren <manige> vrowen wolgetan
| ### Der chvnich was chomen veber vnt manich werder gast ### hei waz starcher sheffte vor den vrowen brast ### man hort da hvrtechlichen von schilden manigen stoz ### hey waz richer pvkelen vor gedrange lvt er doz
###### 583 | ### Di vil minnechlichen stvnden an der habe ### Gvnther mit sinen gesten gie von den shiffen abe ### er fvrte prvnhilden selb an siner hant ### da lvhte wider ein ander vil lieht stein vnt gewant
###### 584 | ### Mit vil grozen zvehten vrov Crimhilt do gie ### do si vrovn Prvnhilden von ir gesinde enpfie ### man sach da shapel rvcken mit liehten henden da ### si sich chvsten beide daz wart dvrch zvht getan
| ### Do sprach gezogenliche Crimhilt daz mægedin ### ir svlt zv disen landen vns willechomen sin ### mir vnt miner mvter vnt allen di wir han ### der getriwen frivnde do wart nigen getan
###### 586 | ### Di vrowen sich beviengen mit armen dike hie ### so minnechlich enpfahen gehorte man noch nie ### so di vrowen bæide der brvete taten chvnt ### vrov vote vnt ir tohter di chvsten dicke ir sovzen mvnt
###### 587 | ### Do frov Prvnnhilt vol chom vf den sant ### si wart vil minnechlichen genomen bi der hant ### von wætlichen recken manich wip wol getan ### man sach di schonen mægede vor vrovn Prvnnhilde stan
| ### E daz ir grvz er gienge daz was ein lange stvnt ### ia wart da gechvsset manich rose varwer mvnt ### noch stvnden bi ein ander di <chvniges> tohter rich ### daz liebte an ce sæhene <vil> manigem recken lobelich
###### 589 | ### Do spæhten mit den ovgen di ê horten iehen ### daz si also shones niht mer hæten [317a] gesæhn ### so di vrowen beide des iach man ane lvge ### ovch chos man an ir libe da dehæiner slahte trvge
###### 590 | ### Di vrowen spæhen chvnden vnt minnechlichen lip ### di lobten dvrch ir shoene daz Gvntheres wip ### do sprachen da di wisen di hæten iz baz gesæhen ### man moehte Crimhilden vor vrovn Prvnnhilden iehen
| ### Wider ein ander <wol> giengen magt vnt wip ### man sach da vol gecieret <vil> manigen shonen lip ### da stvnden siden hvetten vnd manech rich gcelt ### der was gar erfvellet vor Wormez daz velt
###### 592 | ### Vor des chvneges magen wart dringen da getan ### do hiez man Prvnnhilde vnt Criemhilde gan ### vnt mit in alle di vrowen da man schate vant ### da brahten si di dægene vzer bvrgvnden lant
###### 593 | ### Nv waren ovch di geste ce rosse alle chomen ### vil manich richiv tiost dvrch shilt wart genomen ### daz velt begonde stivben sam ob al daz lant ### mit lovge wær er brvnnen da wrden helde wol bechant
| ### Des da di recken pflagen daz sach da manich meit ### mich dvnchet daz her Sifrit mit sinen dægen reit ### vil manige wider chære fver di hvetten dan ### er fvrt der Nibelvnge tvsent wætlicher man
###### 595 | ### Do chom von Tronege Hagene als im der wirt geriet ### den bvohvrt minnechliche do der helt geshiet ### daz si vngestovbet liezzen div vil schonen chint ### des wart do von den gesten gevolget gvetliche sint
###### 596 | ### Do sprach der herre Gernot div ros lazet stan ### vnz ez beginne <chivelen> so svl wir ane van ### dienen shonen wiben fvr den palas wit ### so der chvenich welle riten daz ir vil bereite sit
| ### Do der bvhvrt was cer gangen veber al daz velt ### do giengen chverzewilen vnder manich gecelt ### di ritter zv den vrowen vf hoher vrevden wan ### da vertriben si di stvnde vnz si wolden riten dan
###### 598 | ### Vor abendes nahen do div svnne nider gie ### vnt ez begonde chvolen niht langer man daz lie ### sich hvop gegen der bverge manich man vnt wip ### mit ovgen wart getrivtet vil maniger shonen vrowen lip
###### 599 | ### Da wart von gvten helden vil chleider [317b] ab geriten ### von den hochgemveten nach des landes siten ### vnze fvr den palas der chvnich nider stvnt ### da wart gedient den vrowen so helde hochgemvete tvnt
| ### Do wrden ovch geshæiden di richen chvnegin ### vrov v^te vnt ir tohter di giengen beide hin ### mit ir ingesinde in ein vil witez gadem ### do horte man allenthalben ce vrevden grozen chradem
###### 601 | ### Gerihtet wart daz gesidele der chvnich wolde gan ### ce tisshe mit den gesten do sach man bi im stan ### di shonen Prvnnhilde crone si do trvch ### in des chveneges lande ia was si rich genvch
###### 602 | ### Vil manich her gesidele mit gvten tavelen bereit ### von spise wart gesezet als vns ist geseit ### des si da haben solden wi wenech des gebrast ### do sach man bi dem chvnege vil manigen herlichen gast
| ### Des wirtes chamerære in becken von golde rot ### daz wazer fvr trvogen des wære lvcel not ### ob iv daz iemen sagte daz man diente baz ### ce fvrsten hochgecite ich wolte niht gelovben daz
###### 604 | ### E daz der vogt von rine wazer do genam ### do tet der herre Sifrit als im do gezam ### er mant in siner triwe wes er im ver iach ### ê daz er Prvnnhilt da heime in Islande sach
| ### Er sprach ir svlt gedenchen des mir swor iwer hant ### swenne vrov Prvnnhilt choeme in diz lant ### ir gæbet mir iwer swester wa sint di eide chomen ### ich han an iwer reise michel arbeit genomen
###### 606 | ### Do sprach der chvnich cem gaste ir habet mich reht er mant ### iane sol niht meinæide werden des min hant ### ich wil iz iv fvegen so ich aller beste chan ### do hiez man Criemhilde ce hove fver den chvnich gan
###### 607 | ### Mit ir vil schonen mægden si chomen fver den sal ### do spranch von einer stiege Giselher ce tal ### nv hæizet wider wenden disiv magedin ### niwan min swester eine sol bi dem chvnege sin
| ### Do braht man Criemhilde da man den chvnich vant ### do stvnden ritter edele von maniges fversten lant ### in dem sal witen man hiez si stille stan ### do was div vrov Prvnnhilt wol hin vnz an den tissch gegan [318a]
###### 609 | ### Do sprach der kvnich Gvnther swester vil gemeit ### dvrch dine selbe tvgende lose minen eit ### ich swor dir einen recken vnt wirdet der din man ### so hastv minen willen mit vil grozen triwen getan
###### 610 | ### Do sprach div maget vil edele vil lieber brvder min ### ir svlt mich niht pflægen ia wil ich immer sin ### swi ir mir gebietet daz sol sin getan ### ich wil in loben gerne den ir mir herre gebet ce man
| ### Von lieber ovgen blicke wart Sifrit varwe rot ### ce dienste sich der recke vron Criemhilde bot ### man hiez si zv ein ander an einen rinch do gan ### man vragte ob si gerne næme den vil vætlichen man
###### 612 | ### In magtlichen zvehten shamte si sich ein teil ### iedoch was gelvcke vnt Sifrit vil geil ### daz si in niht versprechen wolde al da cehant ### ovch lobte si ce wibe der edel chvenich von Niderlant
###### 613 | ### Do er si gelobte vnt ovch in div meit ### gvetlich vmbevahen was da vil bereit ### von Sifrides armen daz minnechliche chint ### von helden wart gechvesset div shone Crimhilt sint
| ### <Sich> teilte daz gesinde also daz geshah ### an daz gegensiedele man Sifride sah ### mit Criemhilde sitcen dar diente manich man ### man sach di Niebelvnge mit samt Sifride gan
###### 615 | ### Der chvnich was gesezen vnt Brvennhilt div meit ### do sah si Criemhilde done wart nie so leit ### bi Sifride sitzen weinen si began ### ir vielen heize træhene vber liehtiv wange dan
###### 616 | ### Do sprach der wirt des landes vil liebiv vrowe min ### war vmbe lat ir trveben vil liehter ovgen shin ### ir mvget ivch vrevn balde iv ist vndertan ### min lant vnt mine bvrge vnt manich wætlicher man
| ### Ich mach wol balde wæinen sprach div shoniv meit ### vmb dine svester ist mir von hercen leit ### di sihe ich nahen sitzen dem eigenholden din ### daz mvz ich imer weinen sol si also verdærbet sin
###### 618 | ### Do sprach der chvnich Gvnther ir mvegt wol stille dagen ### ich wil iv zandern ziten disiv mære sagen ### war vmb ich mine swester Sifride han gegæben ### ia mach si mit dem recken immer vrolichen læben
###### 619 | ### Si sprach mich iamert immer ir shone vnt ovch ir zvht ### wess ich war ich mohte ich hæte gerne flvht ### daz ich <iv> nimmer [318b] wolde geligen nahen bi ### irn saget mir wa von Criemhilt <div> Sifrides wine si
| ### Do sprach der chvnich edele ich tvn iz iv wol bechant ### er hat <als> wol bverge als ich vnt witiv lant ### daz wizet sicherliche er ist ein chvnich rich ### dar vmb gan ich <im> ce minnen di schonen magt lobelich
###### 621 | ### Swaz ir der chvnich sagete si hete trveben mvt ### do gahte von den rossen vil manich ritter gvt ### ir bvhvrt wart so herte daz al div bvrch erdoz ### den wirt bisinen gesten vil <harte> sere verdroz
###### 622 | ### Er dahte er læge sanpfer der schonen vrowen bi ### do was er des gedingen niht gar in hercen vri ### im mvse von ir schvlden liebes vil geshæhen ### er begonde vrivntlichen an vrovn Prvnhilde sæhen
| ### Ir ritterschapf di geste bat man abe lan ### der chvnich mit sinem wibe ce bette wolde gan ### vor des sales stigen gesamenten si sich sit ### Criemhilt vnt Prvnnhilt noch was iz an ir beider nit
###### 624 | ### Do chom ir ingesinde dine svmten sich des niht ### ir richen chamærære brahten in div lieht ### sich teilten do di recken der zweir chvnige man ### do sach man vil der dægene <danne> mit Sifride gan
###### 625 | ### Di herren chomen beide da si solden ligen ### do gedaht ietslicher mit minnen an gesigen ### den minnechlichen vrowen daz sempftet in den mvt ### Sifride chverzewile div wart vil grozliche gvt
| ### Do der herre Sifrit bi Criemhilde lach ### vnt er so minnechliche der ivnchvrowen pflach ### mit sinen edelen minnen si wart im so sin lip ### er næme fvr si eine niht tvsent andriv wip
###### 627 | ### Ich sag iv niht mere wi er der vrowen pflach ### nv horet disiv mære wi Gvnther gelach ### bi vrovn Prvnnhilde der ciere dægen ### er hæte dicke sampfter bi andern wiben gelægen
###### 628 | ### Daz volch was im entwichen vrowen vnt man ### do wart div chemenate vil balde zv getan ### er wande er solde trivten ir vil minnechlichen lip ### ia was iz noch vnnahen ê si wrde sin wip
| ### In sabenwizem hemede si an daz bette gie ### do daht der ritter edele nv han iz alliz hie ### des ich ie da <gert> in allen minen tagen ### si mvst im von ir shoene von grozen schvlden wol behagen
###### 630 | ### Div lieht begonde bergen des edeln chvniges hant ### do gie der dægen chvene da [319a] er di vrowen vant ### er leite sich ir nahen sin vrevde div was groz ### di vil minnechlichen der helt mit armen vmbesloz
###### 631 | ### Minnechlich trivten des chvnd er vil began ### ob in div edele vrowe hete lazzen daz getan ### do zvrnde si so sere daz in gemvete daz ### er wande vinden frivnde do vant er vintlichen haz
| ### Si sprach ritter edele ir svlt iz lazen stan ### des ir da habet gedingen ian mag es niht ergan ### ich wil noch magt beliben ir svlt wol merchen daz ### vnz ich div mær erfinde do wart ir Gvnther gahaz
###### 633 | ### Do rang er nach ir minne vnt cerfvrt ir div chleit ### do greif nach einem gvrtel div herlichiv meit ### daz was ein starcher porte den si vmb ir siten trvch ### do tet si dem chvnige grozer leide genvch
###### 634 | ### Di fvoze vnt ovch di hende si im cesamne bant ### si truoch in ceinem nagel vnt hiench in an di want ### do er si slaffes irrite di minne si im verbot ### ia het er von ir creffte vil nach gewnnen den tot
| ### Do begond er vlegen der meister wande sin ### nv loeset min gebende vil edliv chvnegin ### ine trwe iv doch shoniv vrowe nimmer an gesigen ### vnt sol ovch harte selten iv so nahe mer geligen
###### 636 | ### Sine rvchte wi im wære want si vil sanfte lach ### dort mvst er allez hangen di naht vnz an den tach ### vnz der liehte morgen dvrh div venster shein ### ob er ie crapft gewnne div was an sinem libe chlein
###### 637 | ### Nv sagt mir her Gvnther ist iv daz iht leit ### ob ivch gebvnden fvnden sprach div shone meit ### di iwern chamerære von einer vrowen hant ### do sprach der ritter edele daz wrd iv vebele bewant
| ### Ovch het ihes wenich ere sprach der snelle man ### dvrch iwer selber tvgende nv lat mich zv iv gan ### sit daz iv mine <minne> sint also starche leit ### ich sol mit minen henden nimmer rveren iwer chleit
###### 639 | ### Do losete si in balde vnt do sin vf verlie ### wider daz bette er zv der vrowen gie ### er leite sich so verre daz er ir schone wat ### dar nach vil selten rvrte des wold ovch si do haben rat
###### 640 | ### Do chom ovch ir gesinde di brahten in niwiv chleit ### der was in an den morgen harte vil bereit ### swi wol man da gebarte [319b] trvrech was genvch ### der herre von dem lande swi er des tages crhone trvch
| ### Nach siten der si pflagen vnt man dvrch reht begie ### Gvnther vnt Prvnnhilt niht langer daz en lie ### si giengen zv dem mvnster da man di messe sanch ### dar chom ovch her Sifrit sich hvp da grozlich gedranch
###### 642 | ### Nach chvnechlichen eren was in dar bereit ### swaz si da haben solden ir chrone vnt ovch ir chleit ### do wrden si gewihet do daz was getan ### do sach man si alle viere vnder chrone vrolichen stan
###### 643 | ### Vil ivnger swert <degen> da namen sehs hvndert oder baz ### den chvnegin al ceden eren ir svlt wol wizzen daz ### sich hvp vil michel vrevde in der Bvrgende lant ### man horte da scheffte hellen an der swertdægene <hant>
| ### Do sazen in den venstern div schonen mægedin ### si sahen vor in livhten vil maniges schildes schin ### do het sich gescheiden der chvnich von sinen man ### swes iemen ander pflæge man sah den chvnich trvrende gan
###### 645 | ### Im vnt Sifride vngelich stvnt der mvt ### wol wesse waz im wære der edel ritter gvt ### do giench er zv dem chvnige vragen er began ### wi ist iv hint gelvngen daz svlt ir mich nv wizen lan
###### 646 | ### Do sprach der wirt ce dem gaste ich han laster vnt shaden ### want ich han den vbeln tivel heim ce hvse geladen ### do <ich> si wande minnen vil sere si mich bant ### si trvoch mich ceinem nagele vnt hie mich hohe an di want
| ### Da hie ich angestliche di naht vnz an den tach ### ê daz si mich embvnde wi samfte si do lach ### daz sol dir vrivntliche <vf> genade sin gechleit ### do sprach der starche Sifrit ez ist mir werliche leit
###### 648 | ### Des bringe ich dich wol innen vnt lezestv iz ane nit ### ich shaffe daz si hintz so nahe bi dir gelit ### daz sie dich ir minne gesvmet nimmer mer ### der rede was do Gvnther nach sinen arbeiten her
###### 649 | ### Do sprach der herre Sifrit dv maht wol genesen ### ich wene vns vngeliche hinat si gewesen ### mir ist din swester Crimhilt lieber danne der lip ### ez mvz div vrowe Prvnnhilt noch hinat werden din wip [320a]
| ### Er sprach ich chvm noch hinte ce der chemenaten din ### also tovgenlichen in der tarnkappen min ### daz sich miner liste mach niemen wol versten ### so la di chamerære vz zv ir herberge gen
###### 651 | ### So lessche ich den chinden div lieht an der hant ### daz ich si dar inne da bi si dir bechant ### daz ich dir gerne diene so twinge ich dir din wip ### daz dv si hinte minnest oder ich verlivse minen lip
###### 652 | ### Ane daz dv iht trvetest sprach der chvnich do ### di mine lieben vrowen anders pin iches vro ### so tv ir swaz dv wellest vnt næmest ir den lip ### daz sold ich wol verchiesen si ist ein vreislichez wip
| ### Daz nim ich <so> sprach Sifrit vf di triwe min ### daz ich ir niht en minne div shone swester din ### div ist mir vor allen di ich <noch> ie gesach ### vil wol gelovbte der chvenich Gvnther daz Sifrit gesprach
###### 654 | ### Da was von kvrcewile vrevde vnt not ### bvhvrt vnt shallen allez man verbot ### da di vrowen solden gegen dem sale gan ### do hiezen di kamerære di livte von dem wege stan
###### 655 | ### Von rossen vnt von livten gervmet wart der hoff ### der vrowen ietsliche di fvrt ein bissoff ### do si vor den chvnegen ce tissche solden gan ### in volgete an daz gesidele vil manich wætlicher man
| ### Der chvnich in gvtem wane do vrolichen saz ### daz im gelobte Sifrit wol daht er ane daz ### der eine tach in dvhte wol drizech tage lanch ### an siner vrowen minne stvnt aller sin gedanch
###### 657 | ### Er erbeite chvme daz man von tisshe gie ### di schonen Prvnnhilde man do chomen lie ### vnt ovch vrovn Crimhilde bede an ir <gemach> ### hey waz man sneller dægne vor den chvnegen sach
###### 658 | ### Sifrit der herre vil minnechlichen saz ### bi sinem wibe mit vrevden ane haz ### si trvte sine hende mit ir vil wizzer hant ### vnze er ir vor den ovgen sine wesse wenne ver swant
| ### Do si mit im spilte vnt sis niht mer ensach ### zv sinem gesinde div chveneginne sprach ### mich hat des michel wnder wa der chvnich si bechomen ### wer hat im di sinen hende vz den minen genomen
###### 660 | ### Di rede si lie beliben do was er hin gegan ### da er vil chamerære mit den liehten vant stan ### div begond er lehssen den kinden an der hant ### daz er wære Sifrit [320b] daz was Gvnther bechant
###### 661 | ### Wol wesse er waz er wolde do hiez er dannen gan ### mægede vnt vrowen do daz was getan ### der riche chvnech selbe do besloz di tver ### vil starcher rigel zwene warf er snelle darfver
| ### Div lieht verbarch er schiere vnder di bette wat ### eines spils begonde des was do niht rat ### Sifrit der vil starche vnt ovch div vil schoniv meit ### daz was dem chvnige Gvnther beidiv lip vnt leit
###### 663 | ### Sifrit der leit sich nahen der ivnchvrowen bi ### si sprach nv lat iz Gvnther als liep als ich iv si ### daz ir iht arbeite lidet alsam e ### sit getet div vrowe dem chvnen Sifride we
###### 664 | ### Do hal er sine stimme daz er niht ensprah ### Gvnther wol horte swi er sin <niht> ensah ### daz heimlicher dinge von in da niht geschach ### si heten an dem bette vil harte chleinen gemach
| ### Er gebarte sam ez wære Gvnther der chvnich rich ### er vmbsloz mit armen di magt lobelich ### si warf in vz dem bette da bi vf eine banch ### daz im sin hovbt lvte vf einem schamel erclanch
###### 666 | ### Wider vf mit crepffen spranch der chvne man ### er wold iz baz versvchen do er des began ### daz er si wolde twingen dar vmbe wart im vil we ### solech wer von deheiner vrowen div wæne immer mer erge
###### 667 | ### Do er niht wold erwinden div maget vf do spranch ### iren svlt mir niht cerfveren min hemde so blanch ### ir sit vil vngefvege daz sol iv werden leit ### des bringe ich ivch wol innen sprach div wætlichiv meit
| ### Si besloz mit armen den tiwerlichen <dægen> ### do wold si in gebvnden alsam den chvnich legen ### daz si an dem bette mohte haben gemach ### daz er ir di wat cerfvrte div vrowe iz grozlichen rach
###### 669 | ### Waz half sin groziv sterche vnt ovch sin groziv crapft ### si erceigete dem degene <ir> libes meisterschapft ### si trvch in mit gewalte daz mvs et also sin ### vnt drvcht in gevoge zwisschen di want vnd ein schrin
###### 670 | ### Owe daht der recke sol ich nv minen lip ### von einer magt verliesen so mvgen elliv wip ### her nach immer mere tragen gelffen mvt ### gegen ir manne div ez svs nimmer getvt [321a]
| ### Der chvnich ez wol horte er angestete vmb den man ### Sifrit zvrnte sere shamen er sich began ### mit vngefvoger crepfte sazt er sich wider ### er versvchtez angestiliche an vrovn Prvnnhilde sider
###### 672 | ### Den chvnich ez dvhte lange ê er si betwanch ### si drvcht im sine hende daz vz den nageln sprach ### daz plvt im von ir crepfte daz was dem helde leit ### sit braht er an <ein> lovgen di vil herlichen meit
###### 673 | ### ir vngefveges willen des si e da iach ### der kvnich iz allez horte swi er niht ensprach ### er druchtes an daz <bette> daz si vil lvte schre ### ir taten sine crepfte harte grozlichen we
| ### Do greif si hinz ir siten da si den porten vant ### vnt wolt in han gebvnden do wert ez so sin hant ### daz ir div lid ercrachten vnt ovch al der lip ### des wart der strit gescheiden do wart si Gvntheres wip
###### 675 | ### Si sprach chvnich edele dv solt mich læben lan ### ez wirt vil wol versvenet swaz ich dir han getan ### <ichen> gewer mich nimmer mære der ædelen minne din ### ich han daz wol erfvnden daz dv chanst vrowen meister sin
###### 676 | ### Sifrit stvnt dannen ligen lie er di meit ### sam er von im ziehen wolde vil gar siniv chleit ### er zoch ir ab ir hende ein gvldin vingerlin ### daz si des nie wart innen div edle chvnegin
| ### Dar zv nam er ir gvrtel daz was ein porte gvt ### ine weiz ob er daz tæte dvrh sinen hohen mvt ### er gab iz sinem wibe daz wart im sider leit ### do lagen bi ein ander Gvnther vnt div schoniv meit
###### 678 | ### Er pflach ir minnechlichen als im daz gezam ### do mvst si verchiesen ir zorn vnt ovch ir sham ### von siner heimliche si wart ein lvocel bleich ### hey waz ir von der minne ir grozen crepffte entweich
###### 679 | ### Done was ovch si niht stærcher dann ein ander wip ### er trvte minnechliche den ir vil shonen lip ### ob siz versvchte mære waz chvnde daz vervan ### daz het ir allez Gvnther mit sinen minnen getan
| ### Wi rehte minnechliche si do bi im lach ### mit vrivntlicher liebe vnz an den liehten tach ### nv was der herre Sifrit wider vz gegan ### da er wol wart entpfangen von einer vrowen wolgetan
###### 681 | ### Er vnderstvnt ir vrage der si hæte gedaht ### er hal si sit vil lange daz er ir hæte braht ### vnz daz si vnder chrone in sinem lande gie [321b] ### swaz er ir gæben solde wi lvcel erz beliben lie
###### 682 | ### Der wirt wart an dem morgen verrer baz gemvt ### danne er da vor wære des wart div vrevde gvt ### in allem sinem lande von manigem edlem man ### di er ce hvse ladete den wart vil dieneste getan
| ### Div hohzit do wærte vnz an den viercehenden tach ### daz in al der wile nie der shal gelach ### von aller hende vrevden der iemen solde pflægen ### do wart des chvneges choste vil harte hohe gewægen
###### 684 | ### Des edelen wirtes mage als ez der chvenich gebot ### den gaben dvrch sin ere chleider vnt golt vil rot ### ross vnt dar zv silber vil manigem vremdem man ### di da gabe gerten di shieden vrolichen dan
###### 685 | ### Sifrit der herre vzer Niderlant ### mit tvsent sinen mannen alliz ir gewant ### daz si ce Rine brahten wart alliz hin gegæben ### vnt ovch div ross mit sætelen si chvnden herliche leben
###### 686 | ### <E> daz man di riche gabe alle da verswanch ### di wider ce lande wolden di dvhte des ce lanch ### ezen wart nie geste mære baz gepflægen ### so endete sich div hohzit daz wolde Gvnther der dægen

<<< Übersicht <<< vorige Seite nächste Seite >>>